@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import sys
 import load_dot_env
-from _bigbang_core.usecases.import_relationships import ImportRelationships, ACTION_TYPE_SKIP, ACTION_TYPE_UPDATE
+from usecases.import_relationships import ImportRelationships, ACTION_TYPE_SKIP, ACTION_TYPE_UPDATE
 
 DEFAULT_FILE_NAME = 'relationships.csv'
 def main(args = sys.argv):
@@ -36,6 +36,12 @@ def main(args = sys.argv):
     try:
         import_relationships = ImportRelationships(file_name, type_in_row, create_node)
         import_relationships.invoke(action_type)
+        print('[Treated results]')
+        print('created: %s' % (import_relationships.treated["created"]))
+        print('updated: %s' % (import_relationships.treated["updated"]))
+        print('skipped: %s' % (import_relationships.treated["skipped"]))
+        print('failed: %s' % (import_relationships.treated["failed"]))
+
     except Exception as e:
         print(e)
 
